@@ -35,41 +35,34 @@
 #define M_LOG2E 1.44269504088896340736
 #endif
 
-namespace infomap
-{
-	namespace infomath
-	{
-		inline
-		double log2(double p)
-		{
-			return std::log(p) * M_LOG2E; // M_LOG2E == 1 / M_LN2
-		}
+namespace infomap {
+namespace infomath {
+  inline double log2(double p)
+  {
+    return std::log(p) * M_LOG2E; // M_LOG2E == 1 / M_LN2
+  }
 
-		inline
-		double plogp(double p)
-		{
-			return p > 0.0 ? p * log2(p) : 0.0;
-		}
+  inline double plogp(double p)
+  {
+    return p > 0.0 ? p * log2(p) : 0.0;
+  }
 
-		template<typename T, typename U>
-		inline
-		bool isBetween(T value, U lowerLimit, U higherLimit)
-		{
-			return value >= lowerLimit && value <= higherLimit;
-		}
+  template <typename T, typename U>
+  inline bool isBetween(T value, U lowerLimit, U higherLimit)
+  {
+    return value >= lowerLimit && value <= higherLimit;
+  }
 
-		template<typename T, typename U>
-		inline
-		bool isBetweenStrict(T value, U lowerLimit, U higherLimit)
-		{
-			return value > lowerLimit && value < higherLimit;
-		}
+  template <typename T, typename U>
+  inline bool isBetweenStrict(T value, U lowerLimit, U higherLimit)
+  {
+    return value > lowerLimit && value < higherLimit;
+  }
 
-		inline
-		bool isEqualWithinThreshold(double v1, double v2, double epsilon = 1e-10)
-		{
-			return std::abs(v2 - v1) < epsilon;
-		}
-	}
-}
+  inline bool isEqualWithinThreshold(double v1, double v2, double epsilon = 1e-10)
+  {
+    return std::abs(v2 - v1) < epsilon;
+  }
+} // namespace infomath
+} // namespace infomap
 #endif /* INFOMAPTH_H_ */
